@@ -405,7 +405,7 @@ AndroidMediaLibrary::onMediaAdded( std::vector<medialibrary::MediaPtr> mediaList
         JNIEnv *env = getEnv();
         if (env == NULL /*|| env->IsSameObject(weak_thiz, NULL)*/)
             return;
-        jobjectArray mediaRefs;
+        jobjectArray mediaRefs, results;
         int index;
         if (m_mediaAddedType & FLAG_MEDIA_ADDED_AUDIO_EMPTY)
         {
@@ -431,12 +431,14 @@ AndroidMediaLibrary::onMediaAdded( std::vector<medialibrary::MediaPtr> mediaList
             jobject thiz = getWeakReference(env);
             if (thiz)
             {
-                env->CallVoidMethod(thiz, p_fields->MediaLibrary.onMediaAddedId, mediaRefs);
+                results = filteredArray(env, p_fields, mediaRefs, -1);
+                env->CallVoidMethod(thiz, p_fields->MediaLibrary.onMediaAddedId, results);
                 if (weak_compat)
                     env->DeleteLocalRef(thiz);
-            }
+                env->DeleteLocalRef(results);
+            } else
+                env->DeleteLocalRef(mediaRefs);
         }
-        env->DeleteLocalRef(mediaRefs);
     }
 }
 
@@ -447,7 +449,7 @@ void AndroidMediaLibrary::onMediaUpdated( std::vector<medialibrary::MediaPtr> me
         JNIEnv *env = getEnv();
         if (env == NULL)
             return;
-        jobjectArray mediaRefs;
+        jobjectArray mediaRefs, results;
         int index;
         if (m_mediaUpdatedType & FLAG_MEDIA_UPDATED_AUDIO_EMPTY)
         {
@@ -470,14 +472,16 @@ void AndroidMediaLibrary::onMediaUpdated( std::vector<medialibrary::MediaPtr> me
         if (index > -1)
         {
             jobject thiz = getWeakReference(env);
+            results = filteredArray(env, p_fields, mediaRefs, -1);
             if (thiz)
             {
-                env->CallVoidMethod(thiz, p_fields->MediaLibrary.onMediaUpdatedId, mediaRefs);
+                env->CallVoidMethod(thiz, p_fields->MediaLibrary.onMediaUpdatedId, results);
                 if (weak_compat)
                     env->DeleteLocalRef(thiz);
-            }
+                env->DeleteLocalRef(results);
+            } else
+                env->DeleteLocalRef(mediaRefs);
         }
-        env->DeleteLocalRef(mediaRefs);
     }
 }
 
