@@ -89,6 +89,7 @@ import org.videolan.vlc.media.MediaUtils;
 import org.videolan.vlc.media.MediaWrapperList;
 import org.videolan.vlc.util.AndroidDevices;
 import org.videolan.vlc.util.FileUtils;
+import org.videolan.vlc.util.Permissions;
 import org.videolan.vlc.util.Strings;
 import org.videolan.vlc.util.VLCInstance;
 import org.videolan.vlc.util.VLCOptions;
@@ -578,10 +579,12 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
                     changeAudioFocus(true);
                     if (!mWakeLock.isHeld())
                         mWakeLock.acquire();
-                    if (!keyguardManager.inKeyguardRestrictedInputMode() && !mVideoBackground && switchToVideo())
+                    if (!keyguardManager.inKeyguardRestrictedInputMode() && !mVideoBackground && switchToVideo()) {
                         hideNotification();
-                    else
+                    } else {
+                        showPlayer();
                         showNotification();
+                    }
                     mVideoBackground = false;
                     if (getCurrentMediaWrapper().getType() == MediaWrapper.TYPE_STREAM)
                         mMedialibrary.addToHistory(getCurrentMediaLocation(), getCurrentMediaWrapper().getTitle());
@@ -657,6 +660,10 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         }
     };
 
+    private void showPlayer() {
+        sendBroadcast(new Intent(AudioPlayerContainerActivity.ACTION_SHOW_PLAYER));
+    }
+
     public void saveMediaMeta() {
         MediaWrapper media = mMedialibrary.findMedia(getCurrentMediaWrapper());
         if (media == null || media.getId() == 0)
@@ -1072,13 +1079,13 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
 
         mediaButtonIntent.setClass(this, RemoteControlClientReceiver.class);
         PendingIntent mbrIntent = PendingIntent.getBroadcast(this, 0, mediaButtonIntent, 0);
+        ComponentName mbrName = new ComponentName(this, RemoteControlClientReceiver.class);
 
         mSessionCallback = new MediaSessionCallback();
-        mMediaSession = new MediaSessionCompat(this, "VLC");
+        mMediaSession = new MediaSessionCompat(this, "VLC", mbrName, mbrIntent);
         mMediaSession.setFlags(MediaSessionCompat.FLAG_HANDLES_MEDIA_BUTTONS
                 | MediaSessionCompat.FLAG_HANDLES_TRANSPORT_CONTROLS);
         mMediaSession.setCallback(mSessionCallback);
-        mMediaSession.setMediaButtonReceiver(mbrIntent);
         try {
             mMediaSession.setActive(true);
         } catch (NullPointerException e) {
@@ -1683,7 +1690,7 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
 
     @MainThread
     public String getTitlePrev() {
-        if (mPrevIndex != -1)
+        if (isValidIndex(mPrevIndex))
             return mMediaList.getMedia(mPrevIndex).getTitle();
         else
             return null;
@@ -1691,32 +1698,29 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
 
     @MainThread
     public String getTitleNext() {
-        if (mNextIndex != -1)
+        if (isValidIndex(mNextIndex))
             return mMediaList.getMedia(mNextIndex).getTitle();
         else
             return null;
     }
 
     @MainThread
-    public Bitmap getCover() {
-        if (hasCurrentMedia()) {
-            return AudioUtil.getCover(PlaybackService.this, getCurrentMedia(), 512);
-        }
-        return null;
+    public String getCoverArt() {
+        return getCurrentMedia().getArtworkMrl();
     }
 
     @MainThread
-    public Bitmap getCoverPrev() {
-        if (mPrevIndex != -1)
-            return AudioUtil.getCover(PlaybackService.this, mMediaList.getMedia(mPrevIndex), 512);
+    public String getPrevCoverArt() {
+        if (isValidIndex(mPrevIndex))
+            return mMediaList.getMedia(mPrevIndex).getArtworkMrl();
         else
             return null;
     }
 
     @MainThread
-    public Bitmap getCoverNext() {
-        if (mNextIndex != -1)
-            return AudioUtil.getCover(PlaybackService.this, mMediaList.getMedia(mNextIndex), 512);
+    public String getNextCoverArt() {
+        if (isValidIndex(mNextIndex))
+            return mMediaList.getMedia(mNextIndex).getArtworkMrl();
         else
             return null;
     }
@@ -1975,6 +1979,17 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         playIndex(index, 0);
     }
 
+    @MainThread
+    public void flush() {
+        /* HACK: flush when activating a video track. This will force an
+         * I-Frame to be displayed right away. */
+        if (isSeekable()) {
+            long time = getTime();
+            if (time > 0 )
+                setTime(time);
+        }
+    }
+
     /**
      * Use this function to show an URI in the audio interface WITHOUT
      * interrupting the stream.
@@ -2064,6 +2079,39 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         append(arrayList);
     }
 
+    /**
+     * Insert into the current existing playlist
+     */
+
+    @MainThread
+    public void insertNext(MediaWrapper[] mediaList) {
+        insertNext(Arrays.asList(mediaList));
+    }
+
+    @MainThread
+    public void insertNext(List<MediaWrapper> mediaList) {
+        if (!hasCurrentMedia()) {
+            load(mediaList, 0);
+            return;
+        }
+
+        int startIndex = mCurrentIndex + 1;
+
+        for (int i = 0; i < mediaList.size(); i++) {
+            MediaWrapper mediaWrapper = mediaList.get(i);
+            mMediaList.insert(startIndex + i, mediaWrapper);
+        }
+        onMediaListChanged();
+        updateMediaQueue();
+    }
+
+    @MainThread
+    public void insertNext(MediaWrapper media) {
+        ArrayList<MediaWrapper> arrayList = new ArrayList<>();
+        arrayList.add(media);
+        insertNext(arrayList);
+    }
+
     /**
      * Move an item inside the playlist.
      */
@@ -2472,12 +2520,17 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
     @Nullable
     @Override
     public BrowserRoot onGetRoot(@NonNull String clientPackageName, int clientUid, @Nullable Bundle rootHints) {
-        return new BrowserRoot(BrowserProvider.ID_ROOT, null);
+        return Permissions.canReadStorage() ? new BrowserRoot(BrowserProvider.ID_ROOT, null) : null;
     }
 
+    boolean mMLInitializing = false;
     @Override
     public void onLoadChildren(@NonNull final String parentId, @NonNull final Result<List<MediaBrowserCompat.MediaItem>> result) {
         result.detach();
+        if (!mMLInitializing && !mMedialibrary.isInitiated() && BrowserProvider.ID_ROOT.equals(parentId)) {
+            startService(new Intent(MediaParsingService.ACTION_INIT, null, this, MediaParsingService.class));
+            mMLInitializing = true;
+        }
         VLCApplication.runBackground(new Runnable() {
             @Override
             public void run() {
