@@ -90,9 +90,7 @@ public abstract class BaseAudioBrowser extends MediaBrowserFragment implements I
                     mService.append(tracks);
                     break;
                 case R.id.action_mode_audio_add_playlist:
-                    MediaWrapper[] trackList = new MediaWrapper[tracks.size()];
-                    tracks.toArray(trackList);
-                    UiTools.addToPlaylist(getActivity(), trackList);
+                    UiTools.addToPlaylist(getActivity(), tracks);
                     break;
                 case R.id.action_mode_audio_info:
                     showInfoDialog(list.get(0));
