@@ -82,7 +82,7 @@ import org.videolan.vlc.util.VLCInstance;
 import java.util.ArrayList;
 import java.util.List;
 
-public class VideoGridFragment extends MediaBrowserFragment implements MediaUpdatedCb, ISortable, SwipeRefreshLayout.OnRefreshListener, DevicesDiscoveryCb, MediaAddedCb, Filterable, IEventsHandler, View.OnClickListener {
+public class VideoGridFragment extends MediaBrowserFragment implements MediaUpdatedCb, ISortable, SwipeRefreshLayout.OnRefreshListener, DevicesDiscoveryCb, MediaAddedCb, Filterable, IEventsHandler {
 
     public final static String TAG = "VLC/VideoListFragment";
 
@@ -124,7 +124,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         mSearchButtonView = v.findViewById(R.id.searchButton);
 
         mSwipeRefreshLayout.setOnRefreshListener(this);
-        mTextViewNomedia.setOnClickListener(this);
 
         mDividerItemDecoration = new DividerItemDecoration(v.getContext(), DividerItemDecoration.VERTICAL);
         if (mVideoAdapter.isListMode())
@@ -161,7 +160,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         updateViewMode();
         if (mMediaLibrary.isInitiated())
             fillView();
-        else
+        else if (mGroup == null)
             setupMediaLibraryReceiver();
     }
 
@@ -198,9 +197,11 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
     }
 
     protected void fillView() {
-        mMediaLibrary.setMediaUpdatedCb(this, Medialibrary.FLAG_MEDIA_UPDATED_VIDEO);
-        mMediaLibrary.setMediaAddedCb(this, Medialibrary.FLAG_MEDIA_ADDED_VIDEO);
-        mMediaLibrary.addDeviceDiscoveryCb(this);
+        if (mGroup == null) {
+            mMediaLibrary.setMediaUpdatedCb(this, Medialibrary.FLAG_MEDIA_UPDATED_VIDEO);
+            mMediaLibrary.setMediaAddedCb(this, Medialibrary.FLAG_MEDIA_ADDED_VIDEO);
+            mMediaLibrary.addDeviceDiscoveryCb(this);
+        }
         mHandler.sendEmptyMessage(UPDATE_LIST);
     }
 
@@ -652,13 +653,4 @@ public class VideoGridFragment extends MediaBrowserFragment implements MediaUpda
         updateEmptyView();
         setFabPlayVisibility(true);
     }
-
-    @Override
-    public void onClick(View v) {
-        if (v.getId() == R.id.textview_nomedia) {
-            Intent intent = new Intent(v.getContext(), SecondaryActivity.class);
-            intent.putExtra("fragment", SecondaryActivity.STORAGE_BROWSER);
-            startActivity(intent);
-        }
-    }
 }
